// -*- C++ -*-
/*!
 * @file  VSWRC003LV_CTRL_BT.cpp
 * @brief Controll VS-WRC003LV use by Bluetooth
 * @date $Date$
 *
 * $Id$
 */

#include "VSWRC003LV_CTRL_BT.h"

// Module specification
// <rtc-template block="module_spec">
static const char* vswrc003lv_ctrl_bt_spec[] =
  {
    "implementation_id", "VSWRC003LV_CTRL_BT",
    "type_name",         "VSWRC003LV_CTRL_BT",
    "description",       "Controll VS-WRC003LV use by Bluetooth",
    "version",           "1.0.0",
    "vendor",            "Vstone",
    "category",          "Test",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "0",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    "conf.default.BT_port", "44",
    // Widget
    "conf.__widget__.BT_port", "text",
    // Constraints
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
VSWRC003LV_CTRL_BT::VSWRC003LV_CTRL_BT(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_Mt1GainIn("Mt1Gain", m_Mt1Gain),
    m_Mt2GainIn("Mt2Gain", m_Mt2Gain),
    m_Mt1SpdIn("Mt1Spd", m_Mt1Spd),
    m_Mt2SpdIn("Mt2Spd", m_Mt2Spd),
    m_ModeIn("Mode", m_Mode),
    m_AN1Out("AN1", m_AN1),
    m_AN2Out("AN2", m_AN2)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
VSWRC003LV_CTRL_BT::~VSWRC003LV_CTRL_BT()
{
}



RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("Mt1Gain", m_Mt1GainIn);
  addInPort("Mt2Gain", m_Mt2GainIn);
  addInPort("Mt1Spd", m_Mt1SpdIn);
  addInPort("Mt2Spd", m_Mt2SpdIn);
  addInPort("Mode", m_ModeIn);
  
  // Set OutPort buffer
  addOutPort("AN1", m_AN1Out);
  addOutPort("AN2", m_AN2Out);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // Bind variables and configuration variable
  bindParameter("BT_port", m_BT_port, "44");
  
  // </rtc-template>
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onExecute(RTC::UniqueId ec_id)
{
	//{bgƂ̒ʐMԂtO
	static BOOL init_flg=TRUE;
	{
		//ŏ̎sAyѐڑr؂ꂽ̎sł΃{bgƂ̐ڑs
		if(init_flg){
			CWRC_Connect_BT(m_BT_port);
			init_flg=FALSE;
		}

		//{bg̓샂[h
		if(m_ModeIn.isNew()){
			m_ModeIn.read();
			CWRC_WriteMemMap(4,(BYTE) m_Mode.data);
			CWRC_WriteMemMap(5,(BYTE) (m_Mode.data>>8));
			printf("Mode=%d \n",m_Mode.data);
		}

		//{bg̃[^QC
		if(m_Mt1GainIn.isNew()){
			m_Mt1GainIn.read();
			CWRC_WriteMemMap(8,(BYTE) m_Mt1Gain.data);
			printf("Gain1=%d \n",m_Mt1Gain.data);
		}
		if(m_Mt2GainIn.isNew()){
			m_Mt2GainIn.read();
			CWRC_WriteMemMap(9,(BYTE) m_Mt2Gain.data);
			printf("Gain2=%d \n",m_Mt2Gain.data);
		}

		//{bg̃[^Xs[h
		if(m_Mt1SpdIn.isNew()){
			m_Mt1SpdIn.read();
			CWRC_WriteMemMap(14,(BYTE) (m_Mt1Spd.data>>8));
			CWRC_WriteMemMap(15,(BYTE) m_Mt1Spd.data);
			printf("Spd1=%d \n",m_Mt1Spd.data);
		}
		if(m_Mt2SpdIn.isNew()){
			m_Mt2SpdIn.read();
			CWRC_WriteMemMap(16,(BYTE) (m_Mt2Spd.data>>8));
			CWRC_WriteMemMap(17,(BYTE) m_Mt2Spd.data);
			printf("Spd2=%d \n",m_Mt2Spd.data);
		}

		//f[^̑MBG[o玟̍Đڑ̂߁AtOFALSE
		if(!CWRC_WriteExecute(FALSE)){
			CWRC_Disconnect();
			init_flg=TRUE;
		}


		//{bgԊOZT̏擾
		CWRC_ReadMemMap(0x1a,4);

		//f[^̎MBG[o玟̍Đڑ̂߁AtOFALSE
		if(CWRC_ReadExecute()){

			//Mf[^ʂɕ\A|[go
			m_AN1.data = wrc_mem_uw(0x1a);
			m_AN2.data = wrc_mem_uw(0x1c);
			m_AN1Out.write();
			m_AN2Out.write();

			printf("Ain1=%04x , Ain2=%04x\n",wrc_mem_uw(0x1c),wrc_mem_uw(0x1a));
		}
		else{
			CWRC_Disconnect();
			init_flg=TRUE;
		}

	}
	return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VSWRC003LV_CTRL_BT::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void VSWRC003LV_CTRL_BTInit(RTC::Manager* manager)
  {
    coil::Properties profile(vswrc003lv_ctrl_bt_spec);
    manager->registerFactory(profile,
                             RTC::Create<VSWRC003LV_CTRL_BT>,
                             RTC::Delete<VSWRC003LV_CTRL_BT>);
  }
  
};


